@@ -1,6 +1,6 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from ..model import ModelView, ModelSQL, fields, EvalEnvironment
+from ..model import ModelView, ModelSQL, fields, EvalEnvironment, Check
 from ..transaction import Transaction
 from ..cache import Cache
 from ..pool import Pool
@@ -40,10 +40,13 @@ class RuleGroup(ModelSQL, ModelView):
         cls._order.insert(0, ('model', 'ASC'))
         cls._order.insert(1, ('global_p', 'ASC'))
         cls._order.insert(2, ('default_p', 'ASC'))
+
+        t = cls.__table__()
         cls._sql_constraints += [
-            ('global_default_exclusive', 'CHECK(NOT(global_p AND default_p))',
+            ('global_default_exclusive',
+                Check(t, (t.global_p == False) | (t.default_p == False)),
                 'Global and Default are mutually exclusive!'),
-        ]
+            ]
 
     @staticmethod
     def default_global_p():
@@ -191,7 +194,7 @@ class Rule(ModelSQL, ModelView):
                 condition=rule_group.model == model.id
                 ).select(rule_table.id,
                 where=(model.model == model_name)
-                & getattr(rule_group, 'perm_%s' % mode)
+                & (getattr(rule_group, 'perm_%s' % mode) == True)
                 & (rule_group.id.in_(
                         rule_group_user.select(rule_group_user.rule_group,
                             where=rule_group_user.user == user_id)
@@ -202,14 +205,13 @@ class Rule(ModelSQL, ModelView):
                             ).select(rule_group_group.rule_group,
                             where=user_group.user == user_id)
                         )
-                    | rule_group.default_p
-                    | rule_group.global_p
+                    | (rule_group.default_p == True)
+                    | (rule_group.global_p == True)
                     )))
         ids = [x[0] for x in cursor.fetchall()]
         if not ids:
             cls._domain_get_cache.set(key, None)
             return
-        obj = pool.get(model_name)
         clause = {}
         clause_global = {}
         ctx = cls._get_context()
@@ -245,21 +247,33 @@ class Rule(ModelSQL, ModelView):
             group_id = fetchone[0]
             clause[group_id] = []
         clause = clause.values()
-        clause.insert(0, 'OR')
+        if clause:
+            clause.insert(0, 'OR')
 
         clause_global = clause_global.values()
 
         if clause_global:
             clause_global.insert(0, 'AND')
+
+        if clause and clause_global:
             clause = ['AND', clause_global, clause]
+        elif clause_global:
+            clause = clause_global
+
+        cls._domain_get_cache.set(key, clause)
+        return clause
+
+    @classmethod
+    def query_get(cls, model_name, mode='read'):
+        pool = Pool()
+        Model = pool.get(model_name)
+
+        domain = cls.domain_get(model_name, mode=mode)
 
         # Use root to prevent infinite recursion
         with Transaction().set_user(0), \
                 Transaction().set_context(active_test=False, user=0):
-            query = obj.search(clause, order=[], query=True)
-
-        cls._domain_get_cache.set(key, query)
-        return query
+            return Model.search(domain, order=[], query=True)
 
     @classmethod
     def delete(cls, rules):
